powered by
Change the gene by a genetic operator pipeline and return the new gene only if the new gene has at least the same fitness as the gene.
AcceptBest(OperatorPipeline, gene, lF)
The new gene, if it is at least as fit as gene else the old gene gene.
gene
Genetic operator pipeline.
Gene.
Local configuration.
The fitness of genes never decreases. New genes with inferior fitness do not survive.
Other Acceptance Rule: AcceptIVMetropolis(), AcceptMetropolis(), AcceptNewGene()
AcceptIVMetropolis()
AcceptMetropolis()
AcceptNewGene()
OPpipe1<-function(g, lF){InitGene(lF)} g1<-lFxegaGaGene$EvalGene(InitGene(lFxegaGaGene), lFxegaGaGene) g2<-AcceptBest(OPpipe1, g1, lFxegaGaGene) identical(g1, g2)
Run the code above in your browser using DataLab