The basic idea is to apply crossover to a gene whose
fitness is below a threshold value with higher probability
to give it a chance
to improve. The threshold value is computed by
lF$CutoffFit()*lF$CBestFitness().
Usage
IACRate(fit, lF)
Value
Crossover rate of a gene depending on its fitness.
Arguments
fit
Fitness of gene.
lF
Local configuration.
Details
The following constants are used:
lF$CrossRate1()<lF$CrossRate2(), and
lF$CutoffFit() in [0, 1].
References
Stanhope, Stephen A. and Daida, Jason M. (1996)
An Individually Variable Mutation-rate Strategy for Genetic Algorithms.
In: Koza, John (Ed.)
Late Breaking Papers at the Genetic Programming 1996 Conference.
Stanford University Bookstore, Stanford, pp. 177-185.
(ISBN:0-18-201-031-7)