Learn R Programming

xegaPopulation (version 1.0.0.12)

IAMRate: Individually adaptive mutation rate.

Description

The probability of applying a mutation operator to a gene. The idea is that a gene selected for reproduction whose fitness is below a threshold value is mutated with a higher probability to give it a chance.

Usage

IAMRate(fit, lF)

Value

Mutation rate of a gene depending on its fitness.

Arguments

fit

Fitness of gene.

lF

Local configuration.

Details

The probability of applying a mutation operator is determined by a threshold: If the fitness of a gene is higher than lF$CutoffFit()*lF$CBestFitness(), than return lF$MutationRate1() else lF$MutationRate2().

Note that the idea is also applicable to gene specific local mutation operators. For example, the bit mutation rate of mutation operators for binary genes.

References

Stanhope, Stephen A. and Daida, Jason M. (1996) An Individually Variable Mutation-rate Strategy for Genetic Algorithms. In: Koza, John (Ed.) Late Breaking Papers at the Genetic Programming 1996 Conference. Stanford University Bookstore, Stanford, pp. 177-185. (ISBN:0-18-201-031-7)

See Also

Other Adaptive Rates: IACRate()

Examples

Run this code
parm<-function(x){function() {return(x)}}
lF<-list()
lF$MutationRate1<-parm(0.20)
lF$MutationRate2<-parm(0.40)
lF$CutoffFit<-parm(0.60)
lF$CBestFitness=parm(105)
IAMRate(100, lF)
IAMRate(50, lF)

Run the code above in your browser using DataLab