This schedule decreases by the inverse proportion of the
natural logarithm
of k. lF$Alpha() should be larger than 1.
Usage
LogarithmicMultiplicativeCooling(k, lF)
Value
Temperature at time k.
Aarts, E., and Korst, J. (1989):
Simulated Annealing and Boltzmann Machines.
A Stochastic Approach to Combinatorial Optimization and
Neural Computing.
John Wiley & Sons, Chichester.
(ISBN:0-471-92146-7)
Arguments
k
Number of steps to discount.
lF
Local configuration.
Details
Temperature is updated at the end of each generation
in the main loop of the genetic algorithm.
lF$Temp0() is the starting temperature.
lF$Alpha() is a scaling factor.
See Also
Other Cooling:
ExponentialAdditiveCooling(),
ExponentialMultiplicativeCooling(),
PowerAdditiveCooling(),
PowerMultiplicativeCooling(),
TrigonometricAdditiveCooling()