PowerMultiplicativeCooling: Power multiplicative cooling.
Description
This schedule decreases by the inverse proportion of
a power
of k. lF$Alpha() should be larger than 1.
Usage
PowerMultiplicativeCooling(k, lF)
Value
Temperature at time k.
Arguments
k
Number of steps to discount.
lF
Local configuration.
Details
Temperature is updated at the end of each generation
in the main loop of the genetic algorithm.
For lF$CoolingPower()==1 and
lF$CoolingPower()==2 this results in the
the linear and quadratic multiplicative cooling schemes
in A Comparison of Cooling Schedules for Simulated Annealing.
lF$Temp0() is the starting temperature.
lF$Alpha() is a scaling factor.
lF$CoolingPower() is an exponential factor.
References
The-Crankshaft Publishing (2023)
A Comparison of Cooling Schedules for Simulated Annealing.
<https://what-when-how.com/artificial-intelligence/a-comparison-of-cooling-schedules-for-simulated-annealing-artificial-intelligence/>
See Also
Other Cooling:
ExponentialAdditiveCooling(),
ExponentialMultiplicativeCooling(),
LogarithmicMultiplicativeCooling(),
PowerAdditiveCooling(),
TrigonometricAdditiveCooling()