TerminationFactory() implements the selection
of a termination method.
Current support:
"NoTermination" returns
terminatedFalse. (Default)
"AbsoluteError" returns
terminateAbsoluteError().
For benchmark functions with known global optima.
Termination condition is fulfilled if the current
best solution is in the interval
from (globalOptimum-eps) to (globalOptimum+eps).
"RelativeError" returns
terminateRelativeError().
For benchmark functions with known global optima.
Termination condition is fulfilled if the current
best solution is in the interval
from (globalOptimum-(globalOptimum*eps)) to
(globalOptimum+(globalOptimum*eps)).
Does not specify an interval if globalOptimum is zero.
"RelativeErrorZero" returns
terminateRelativeErrorZero().
For benchmark functions with known global optima.
Termination condition is fulfilled if the current
best solution is in the interval
from (globalOptimum-(globalOptimum*eps)) to
(globalOptimum+(globalOptimum*eps)).
If the globalOptimum is zero, the interval is
from -terminationEps to terminationEps.
"PAC" returns terminatePAC(). Terminates, as soon as the fitness is
is better than a confidence interval depending on the mean
and stats::qnorm(PACdelta, lower.tail=FALSE)
times the standard deviation of the fitness of the initial population.
"GEQ" returns terminateGEQ(). Terminates as soon as the
phenotype value of the solution is greater equal than lF$TerminationThreshol().
"LEQ" returns terminateLEQ(). Terminates as soon as the
phenotype value of the solution is less equal than lF$TerminationThreshol().
TerminationFactory(method = "NoTermination")A boolean function implementing the termination condition.
A string specifying the termination condition.
Other Configuration:
AcceptFactory(),
ApplyFactory(),
CoolingFactory(),
CrossRateFactory(),
MutationRateFactory(),
checkTerminationFactory(),
xegaAsPipelineFactory(),
xegaConfiguration(),
xegaEvalPopulationFactory()