Learn R Programming

xegaPopulation (version 1.0.0.12)

asPipeline: Converts a population into a list of genetic operator pipelines.

Description

Converts a population into a list of genetic operator pipelines.

Usage

asPipeline(pop, lF)

Value

A list of genetic operator pipelines (closures).

Arguments

pop

A population.

lF

The local function configuration.

See Also

Other Genetic operator pipelines: asPipelineG(), asPipelineID(), xegaRepairPop()

Examples

Run this code
pop5<-xegaInitPopulation(5, lFxegaGaGene)
pop5c<-asPipeline(pop5, lFxegaGaGene)

Run the code above in your browser using DataLab