Learn R Programming

xegaPopulation (version 1.0.0.12)

asPipelineG: Embeds genetic operator pipelines into the genes of a population.

Description

Embeds genetic operator pipelines into the genes of a population.

Usage

asPipelineG(pop, lF)

Value

A population of genes with embedded genetic operator pipelines.

Arguments

pop

A population.

lF

The local function configuration.

See Also

Other Genetic operator pipelines: asPipeline(), asPipelineID(), xegaRepairPop()

Examples

Run this code
pop5<-xegaInitPopulation(5, lFxegaGaGene)
pop5c<-asPipelineG(pop5, lFxegaGaGene)

Run the code above in your browser using DataLab