Learn R Programming

xegaPopulation (version 1.0.0.12)

checkTerminationFactory: Configure consistency checks and adapt penv for terminationConditions.

Description

For each termination condition, a check must be provided. A check fails (stops) if the consistency requirements of a termination condition are not fulfilled. However, a check may modify the problem environment to establish consistency.

Usage

checkTerminationFactory(method = "NoTermination")

Value

A check function.

Arguments

method

A string specifying the termination condition.

See Also

Other Configuration: AcceptFactory(), ApplyFactory(), CoolingFactory(), CrossRateFactory(), MutationRateFactory(), TerminationFactory(), xegaAsPipelineFactory(), xegaConfiguration(), xegaEvalPopulationFactory()