Learn R Programming

xegaPopulation (version 1.0.0.12)

xegaAsPipelineFactory: Configure asPipeline.

Description

xegaAsPipelineFactory() implements the selection of one of the asPipeline functions in this package by specifying a text string. The selection fails ungracefully (produces a runtime error) if the label does not match. The functions are specified locally.

Current support:

  1. "NoPipe" returns asPipelineID(): No change to population.

  2. "PipeC" returns asPipeline(): Population a list of closures of genetic operator populations.

  3. "PipeG" returns asPipelineG(): Population consists of genes with embedded genetic operator pipelines.

Usage

xegaAsPipelineFactory(method = "NoPipe")

Value

An asPipeline function.

Arguments

method

A string specifying the asPipeline function.

See Also

Other Configuration: AcceptFactory(), ApplyFactory(), CoolingFactory(), CrossRateFactory(), MutationRateFactory(), TerminationFactory(), checkTerminationFactory(), xegaConfiguration(), xegaEvalPopulationFactory()

Examples

Run this code
xegaAsPipelineFactory("PipeC")

Run the code above in your browser using DataLab