Learn R Programming

xegaPopulation (version 1.0.0.12)

xegaEvalPopulation: Evaluates a population of genes in a problem environment

Description

xegaEvalPopulation() evaluates a population of genes in a problem environment.

Usage

xegaEvalPopulation(pop, lF)

Value

List of

  • $pop gene vector,

  • $fit fitness vector,

  • $evalFail number of failed evaluations.

Arguments

pop

Population of genes.

lF

Local function configuration.

Details

Parallelization of the evaluation of fitness functions is possible by defining lF$lapply.

See Also

Other Population Layer: xegaBestGeneInPopulation(), xegaBestInPopulation(), xegaInitPopulation(), xegaLogEvalsPopulation(), xegaNextPopulation(), xegaObservePopulation(), xegaRepEvalPopulation(), xegaSummaryPopulation()

Examples

Run this code
pop5<-xegaInitPopulation(5, lFxegaGaGene)
lFxegaGaGene[["lapply"]]<-ApplyFactory(method="Sequential") 
result<-xegaEvalPopulation(pop5, lFxegaGaGene)
result
lFxegaGaGene$Pipeline<-function() {"PipeC"}
pop5c<-asPipeline(pop5, lFxegaGaGene)
pop5c
result<-xegaEvalPopulation(pop5c, lFxegaGaGene)
result
lFxegaGaGene$Pipeline<-function() {"PipeG"}
pop5c<-asPipelineG(pop5, lFxegaGaGene)
pop5c
result<-xegaEvalPopulation(pop5c, lFxegaGaGene)
result

Run the code above in your browser using DataLab