Learn R Programming

xegaPopulation (version 1.0.0.12)

xegaEvalPopulationFactory: Configures the evaluation of the population of a genetic algorithm.

Description

xegaEvalPopulationFactory() implements the selection of the evaluation function for the population of a genetic algorithm.

Current support:

  1. "EvalPopulation" returns xegaEvalPopulation. (Default)

  2. "RepEvalPopulation" returns xegaReplEvalPopulation. For stochastic functions. Needs lF$rep() for the number of repetitions and lF$apply() for the (parallel) apply function.

Usage

xegaEvalPopulationFactory(method = "EvalPopulation")

Value

A boolean function implementing the termination condition.

Arguments

method

A string specifying the termination condition.

See Also

Other Configuration: AcceptFactory(), ApplyFactory(), CoolingFactory(), CrossRateFactory(), MutationRateFactory(), TerminationFactory(), checkTerminationFactory(), xegaAsPipelineFactory(), xegaConfiguration()