Learn R Programming

xegaPopulation (version 1.0.0.12)

xegaRepEvalPopulation: Evaluates a population of genes in a a problem environment repeatedly.

Description

xegaRepEvalPopulation() evaluates a population of genes in a problem environment lF$rep times. The results of repeatedly evaluating a gene are aggregated:

  • gene$fit is the mean fitness,

  • gene$var is the fitness variance,

  • gene$std is the standard deviation of the fitness, and

  • gene$obs is the number of repetitions.

Usage

xegaRepEvalPopulation(pop, lF)

Value

List of

  • $pop gene vector,

  • $fit fitness vector,

  • $evalFail number of failed evaluations.

Arguments

pop

Population of genes.

lF

Local function configuration.

Details

Parallelization of the evaluation of fitness functions is possible by defining lF$lapply.

xegaRepEvalPopulation is still experimental. Known problems (TODOs):

  • The apply loop must be order stable. This does not work e.g. for all local area network distribution versions.

  • Populations of function closures can not be evaluated.

  • Does not work with pipeline compilation.

See Also

Other Population Layer: xegaBestGeneInPopulation(), xegaBestInPopulation(), xegaEvalPopulation(), xegaInitPopulation(), xegaLogEvalsPopulation(), xegaNextPopulation(), xegaObservePopulation(), xegaSummaryPopulation()

Examples

Run this code
    parm<-function(x){function() {return(x)}}
pop10<-xegaInitPopulation(10, lFxegaGaGene)
lFxegaGaGene[["lapply"]]<-ApplyFactory(method="Sequential") 
lFxegaGaGene[["rep"]]<-parm(3) 
result<-xegaRepEvalPopulation(pop10, lFxegaGaGene)

Run the code above in your browser using DataLab