Learn R Programming

xegaPopulation (version 1.0.0.12)

xegaRepairPop: Repairs the list structure of a population of genes.

Description

Pipelines with crossover operators with 2 kids generate function closures which return 2 genes (with the complete genetic material). The resulting population has elements with a single gene and elements with a list of two genes. xegaRepairPop removes this extra nesting structure and returns of population vector of genes of length popsize.

Usage

xegaRepairPop(pop)

Value

A population of genes.

Arguments

pop

A population of genes.

See Also

Other Genetic operator pipelines: asPipeline(), asPipelineG(), asPipelineID()