Learn R Programming

xegaPopulation (version 1.0.0.12)

xegaSummaryPopulation: Provide elementary summary statistics of the fitness of the population.

Description

SummaryPopulation() reports on the fitness and the value of the best solution in the population.

The value of lF$Verbose() controls the information displayed:

  1. == 0: Nothing is displayed.

  2. == 1: 1 point per generation.

  3. > 1: Max(fit), number of solutions, indices.

  4. > 2: and population fitness statistics.

  5. > 3: and 1 solution.

Usage

xegaSummaryPopulation(pop, fit, lF, iter = 0)

Value

The number 0.

Arguments

pop

Population of genes.

fit

Vector of fitness values of pop.

lF

Local function configuration.

iter

The generation. Default: 0.

See Also

Other Population Layer: xegaBestGeneInPopulation(), xegaBestInPopulation(), xegaEvalPopulation(), xegaInitPopulation(), xegaLogEvalsPopulation(), xegaNextPopulation(), xegaObservePopulation(), xegaRepEvalPopulation()

Examples

Run this code
pop10<-xegaInitPopulation(10, lFxegaGaGene)
epop10<-xegaEvalPopulation(pop10, lFxegaGaGene)
rc<-xegaSummaryPopulation(epop10$pop, epop10$fit, lFxegaGaGene, iter=12)

Run the code above in your browser using DataLab