powered by
Embeds genetic operator pipelines into the genes of a population.
asPipelineG(pop, lF)
A population of genes with embedded genetic operator pipelines.
A population.
The local function configuration.
Other Genetic operator pipelines: asPipeline(), asPipelineID(), xegaRepairPop()
asPipeline()
asPipelineID()
xegaRepairPop()
pop5<-xegaInitPopulation(5, lFxegaGaGene) pop5c<-asPipelineG(pop5, lFxegaGaGene)
Run the code above in your browser using DataLab