powered by
xegaBestGeneInPopulation() extracts the indices of the best genes in the population.
xegaBestGeneInPopulation()
xegaBestGeneInPopulation(fit)
List of the indices of the best genes in the population.
Fitness vector of a population of genes.
You might use: which(max(fit)==fit). But this is slower!
which(max(fit)==fit)
Other Population Layer: xegaBestInPopulation(), xegaEvalPopulation(), xegaInitPopulation(), xegaLogEvalsPopulation(), xegaNextPopulation(), xegaObservePopulation(), xegaRepEvalPopulation(), xegaSummaryPopulation()
xegaBestInPopulation()
xegaEvalPopulation()
xegaInitPopulation()
xegaLogEvalsPopulation()
xegaNextPopulation()
xegaObservePopulation()
xegaRepEvalPopulation()
xegaSummaryPopulation()
pop10<-xegaInitPopulation(10, lFxegaGaGene) epop10<-xegaEvalPopulation(pop10, lFxegaGaGene) xegaBestGeneInPopulation(epop10$fit)
Run the code above in your browser using DataLab