Update of the evaluation log.
The evaluation log is a list of decoded and evaluated genes.
A list item of the evaluation log has the following
elements:
$generation: The generation.
$fit: The fitness value.
$sigma: The standard deviation of the
fitness value, if it exists.
Default: 0.
$obs: The number of observations for
computing the
fitness value, if it exists.
Default: 0.
$phenotype: The phenotype of the gene.
Arguments
pop
Population.
evallog
Evaluation log.
generation
Generation logged.
lF
Local function configuration.
See Also
Other Population Layer:
xegaBestGeneInPopulation(),
xegaBestInPopulation(),
xegaEvalPopulation(),
xegaInitPopulation(),
xegaNextPopulation(),
xegaObservePopulation(),
xegaRepEvalPopulation(),
xegaSummaryPopulation()