Pipelines with crossover operators with 2 kids
generate function closures which return 2 genes (with the
complete genetic material). The resulting population has
elements with a single gene and elements with a list of
two genes.
xegaRepairPop removes this extra nesting structure
and returns of population vector of genes of length popsize.
xegaRepairPop(pop)A population of genes.
A population of genes.
Other Genetic operator pipelines:
asPipeline(),
asPipelineG(),
asPipelineID()